---
title: <span class="badge object-type-enum"></span> TimelineValueAlignment
---
# <span class="badge object-type-enum"></span> TimelineValueAlignment

Controls the value alignment in the TimelineChart component

## Definition

```python
class TimelineValueAlignment(enum.StrEnum):
    """
    Controls the value alignment in the TimelineChart component
    """

    CENTER = "center"
    LEFT = "left"
    RIGHT = "right"
```
